pub struct SpaceInfo {
pub space: Option<String>,
}Expand description
Information about the Chat Space where a task was assigned from.
This type is not used in any activity, and only used as part of another schema.
Fields
space: Option<String>Output only. The Chat space where this task originates from. The format is “spaces/{space}”.